diff --git a/assets/css/components/comments/ui.css b/assets/css/components/comments/ui.css
index 3d9ade23..1557c33a 100644
--- a/assets/css/components/comments/ui.css
+++ b/assets/css/components/comments/ui.css
@@ -8,7 +8,7 @@
padding: 10px;
}
-.post-comments .comment-img-contener {
+.post-comments .comment-img-container {
text-align: center;
}
diff --git a/assets/css/components/notifications/ui.css b/assets/css/components/notifications/ui.css
index c9c127e9..0531b0ee 100644
--- a/assets/css/components/notifications/ui.css
+++ b/assets/css/components/notifications/ui.css
@@ -4,10 +4,10 @@
* @author Pierre HUBERT
*/
-.notification-contener p {
+.notification-container p {
white-space: normal;
}
-.notification-contener .notification-creation-time {
+.notification-container .notification-creation-time {
color: #888888;
}
\ No newline at end of file
diff --git a/assets/css/components/posts/form.css b/assets/css/components/posts/form.css
index 397703ff..9a736456 100644
--- a/assets/css/components/posts/form.css
+++ b/assets/css/components/posts/form.css
@@ -64,23 +64,23 @@
/**
* Visibility choice
*/
-.post-form .post-visiblity-contener {
+.post-form .post-visiblity-container {
display: inline-block;
margin-right: 10px;
}
-.post-form .post-visiblity-contener label {
+.post-form .post-visiblity-container label {
margin-left: 5px;
}
-.post-form .post-visiblity-contener input {
+.post-form .post-visiblity-container input {
display: none;
}
-.post-form .post-visiblity-contener span {
+.post-form .post-visiblity-container span {
color: #b5bbc8;
}
-.post-form .post-visiblity-contener input:checked ~ span {
+.post-form .post-visiblity-container input:checked ~ span {
color: #111111;
}
\ No newline at end of file
diff --git a/assets/css/components/posts/ui.css b/assets/css/components/posts/ui.css
index a7eed3bf..93f936dd 100644
--- a/assets/css/components/posts/ui.css
+++ b/assets/css/components/posts/ui.css
@@ -81,7 +81,7 @@
text-align: center;
}
-.post .post-survey-chart-contener {
+.post .post-survey-chart-container {
margin-bottom: 10px;
}
diff --git a/assets/css/pages/userPage/main.css b/assets/css/pages/userPage/main.css
index 78066750..b4f90fb4 100644
--- a/assets/css/pages/userPage/main.css
+++ b/assets/css/pages/userPage/main.css
@@ -4,7 +4,7 @@
* @author Pierre HUBERT
*/
-.page-contener {
+.page-container {
max-width: 1500px;
margin: auto;
}
\ No newline at end of file
diff --git a/assets/js/common/functionsSchema.js b/assets/js/common/functionsSchema.js
index dbddabfa..06fb47bc 100644
--- a/assets/js/common/functionsSchema.js
+++ b/assets/js/common/functionsSchema.js
@@ -189,7 +189,7 @@ var ComunicWeb = {
/**
* Load, parse and show an HTML template
*/
- getAndShowTemplate: function(targetElem, dataTemplate, templateURI, nextAction, cleanContener){},
+ getAndShowTemplate: function(targetElem, dataTemplate, templateURI, nextAction, cleanContainer){},
/**
* Convert a JSON object into html elements
@@ -199,7 +199,7 @@ var ComunicWeb = {
/**
* Get and show a JSON template
*/
- getAndShowJSONtemplate: function(targetElem, templateURI, additionalData, afterParsingJSONtemplate, cleanContener){},
+ getAndShowJSONtemplate: function(targetElem, templateURI, additionalData, afterParsingJSONtemplate, cleanContainer){},
},
/**
@@ -230,7 +230,7 @@ var ComunicWeb = {
network: {
/**
- * @var {object} Cache contener
+ * @var {object} Cache container
*/
cache: {},
diff --git a/assets/js/common/messages.js b/assets/js/common/messages.js
index a36f2686..0ac3ed7c 100644
--- a/assets/js/common/messages.js
+++ b/assets/js/common/messages.js
@@ -19,7 +19,7 @@ ComunicWeb.common.messages.createCalloutElem = function(calloutTitle, calloutMes
if(!calloutType)
var calloutType = "info";
- //Create callout main contener
+ //Create callout main container
var calloutElem = document.createElement('div');
calloutElem.className = "callout callout-" + calloutType;
diff --git a/assets/js/common/network.js b/assets/js/common/network.js
index a9d72280..a79e708e 100644
--- a/assets/js/common/network.js
+++ b/assets/js/common/network.js
@@ -7,7 +7,7 @@
ComunicWeb.common.network = {
/**
- * @var {object} Cache contener
+ * @var {object} Cache container
*/
cache: {},
@@ -100,7 +100,7 @@ ComunicWeb.common.network = {
//Check if error message exists or not
if(!byId("networkErrorMessage")){
- //Create error message contener
+ //Create error message container
var networkErrorMessage = createElem("div", document.body);
networkErrorMessage.id = "networkErrorMessage";
diff --git a/assets/js/common/utils.js b/assets/js/common/utils.js
index bd05e3d4..36e87958 100644
--- a/assets/js/common/utils.js
+++ b/assets/js/common/utils.js
@@ -289,7 +289,7 @@ function createFormGroup(infos){
*/
function create_radio(target, name, label){
- //Contener
+ //Container
var radioDiv = createElem2({
appendTo: target,
type: "div",
diff --git a/assets/js/components/comments/form.js b/assets/js/components/comments/form.js
index d6428ad2..56f8e156 100644
--- a/assets/js/components/comments/form.js
+++ b/assets/js/components/comments/form.js
@@ -16,7 +16,7 @@ ComunicWeb.components.comments.form = {
//Check if we are creating a new comment of or reseting an existing one
if(target.className != "comment-creation-form"){
- //Create form contener
+ //Create form container
var commentForm = createElem2({
appendTo: target,
type: "form",
diff --git a/assets/js/components/conversations/manager.js b/assets/js/components/conversations/manager.js
index ae092719..b04e858c 100644
--- a/assets/js/components/conversations/manager.js
+++ b/assets/js/components/conversations/manager.js
@@ -7,9 +7,9 @@
ComunicWeb.components.conversations.manager = {
/**
- * @var {String} The ID of the conversation contener
+ * @var {String} The ID of the conversation container
*/
- __conversationsContenerID: "conversationsElem",
+ __conversationsContainerID: "conversationsElem",
/**
* Display conversations manager
@@ -19,7 +19,7 @@ ComunicWeb.components.conversations.manager = {
display: function(){
//Try to get conversation manager
- var conversationsContainerElem = byId(this.__conversationsContenerID);
+ var conversationsContainerElem = byId(this.__conversationsContainerID);
//Check if element exists or not
if(conversationsContainerElem){
@@ -33,7 +33,7 @@ ComunicWeb.components.conversations.manager = {
//Create conversations manager element
var conversationsContainerElem = createElem("div");
- conversationsContainerElem.id = this.__conversationsContenerID;
+ conversationsContainerElem.id = this.__conversationsContainerID;
//Insert the element at the right place
var pageTarget = byId("pageTarget");
diff --git a/assets/js/components/conversations/unreadDropdown.js b/assets/js/components/conversations/unreadDropdown.js
index 3971fd34..7344143c 100644
--- a/assets/js/components/conversations/unreadDropdown.js
+++ b/assets/js/components/conversations/unreadDropdown.js
@@ -55,12 +55,12 @@ ComunicWeb.components.conversations.unreadDropdown = {
});
//Add conversations list
- var conversationsListContener = createElem2({
+ var conversationsListContainer = createElem2({
appendTo: dropdownMenu,
type: "li"
});
var conversationsList = createElem2({
- appendTo: conversationsListContener,
+ appendTo: conversationsListContainer,
type: "ul",
class: "menu"
});
diff --git a/assets/js/components/notifications/dropdown.js b/assets/js/components/notifications/dropdown.js
index b3da84c9..50410a75 100644
--- a/assets/js/components/notifications/dropdown.js
+++ b/assets/js/components/notifications/dropdown.js
@@ -72,12 +72,12 @@ ComunicWeb.components.notifications.dropdown = {
});
//Add notifications list
- var notificationsListContener = createElem2({
+ var notificationsListContainer = createElem2({
appendTo: dropdownMenu,
type: "li"
});
var notificationsList = createElem2({
- appendTo: notificationsListContener,
+ appendTo: notificationsListContainer,
type: "ul",
class: "menu"
});
diff --git a/assets/js/components/notifications/ui.js b/assets/js/components/notifications/ui.js
index 621a4f52..97e15c1f 100644
--- a/assets/js/components/notifications/ui.js
+++ b/assets/js/components/notifications/ui.js
@@ -88,15 +88,15 @@ ComunicWeb.components.notifications.ui = {
};
//Create the notification object
- var notificationContener = createElem2({
+ var notificationContainer = createElem2({
appendTo: target,
type: "li",
- class: "notification-contener"
+ class: "notification-container"
});
//Create notification link
var notificationLink = createElem2({
- appendTo: notificationContener,
+ appendTo: notificationContainer,
type: "a"
});
notificationLink.onclick = action;
diff --git a/assets/js/components/posts/edit.js b/assets/js/components/posts/edit.js
index 20e6349c..39ad23fa 100644
--- a/assets/js/components/posts/edit.js
+++ b/assets/js/components/posts/edit.js
@@ -96,7 +96,7 @@ ComunicWeb.components.posts.edit = {
var updateDiv = createElem2({
appendTo: modalBody,
type: "div",
- class: "editor-contener"
+ class: "editor-container"
});
//Create update editor
diff --git a/assets/js/components/posts/form.js b/assets/js/components/posts/form.js
index 42323df8..9366adcf 100644
--- a/assets/js/components/posts/form.js
+++ b/assets/js/components/posts/form.js
@@ -44,36 +44,36 @@ ComunicWeb.components.posts.form = {
$(inputMessageDiv).wysiwyg();
//Add the different post types
- var postTypesContener = createElem2({
+ var postTypesContainer = createElem2({
appendTo: boxBody,
type: "div",
class: "post-types"
});
//Text
- var textType = this._add_post_type(postTypesContener, "text", lang("_post_type_text"));
+ var textType = this._add_post_type(postTypesContainer, "text", lang("_post_type_text"));
textType.checked = true;
//Image
- var imageType = this._add_post_type(postTypesContener, "image", " "+lang("_post_type_image")+"");
+ var imageType = this._add_post_type(postTypesContainer, "image", " "+lang("_post_type_image")+"");
//Youtube
- var youtubeType = this._add_post_type(postTypesContener, "youtube", " "+lang("_post_type_youtube")+"");
+ var youtubeType = this._add_post_type(postTypesContainer, "youtube", " "+lang("_post_type_youtube")+"");
//Movie
- var movieType = this._add_post_type(postTypesContener, "movie", " "+lang("_post_type_movie")+"");
+ var movieType = this._add_post_type(postTypesContainer, "movie", " "+lang("_post_type_movie")+"");
//Link
- var linkType = this._add_post_type(postTypesContener, "link", " "+lang("_post_type_link")+"");
+ var linkType = this._add_post_type(postTypesContainer, "link", " "+lang("_post_type_link")+"");
//PDF
- var pdfType = this._add_post_type(postTypesContener, "pdf", " "+lang("_post_type_pdf")+"");
+ var pdfType = this._add_post_type(postTypesContainer, "pdf", " "+lang("_post_type_pdf")+"");
//Countdown timer
- var countdownType = this._add_post_type(postTypesContener, "countdown", " "+lang("_post_type_countdown")+"");
+ var countdownType = this._add_post_type(postTypesContainer, "countdown", " "+lang("_post_type_countdown")+"");
//Survey
- var surveyType = this._add_post_type(postTypesContener, "survey", " "+lang("_post_type_survey")+"");
+ var surveyType = this._add_post_type(postTypesContainer, "survey", " "+lang("_post_type_survey")+"");
@@ -255,7 +255,7 @@ ComunicWeb.components.posts.form = {
countdownType.onclick = changesHandler;
surveyType.onclick = changesHandler;
- //Right contener
+ //Right container
var rightDiv = createElem2({
appendTo: boxBody,
type: "div",
@@ -263,24 +263,24 @@ ComunicWeb.components.posts.form = {
})
//Add visibility level choice
- var visibility_choices_contener = createElem2({
+ var visibility_choices_container = createElem2({
appendTo: rightDiv,
type: "div",
- class: "post-visiblity-contener"
+ class: "post-visiblity-container"
});
//Private post
var privateLevel = ComunicWeb.components.posts.visibilityLevels.private;
- var privateInput = this._add_visiblity_choice(visibility_choices_contener, "private", privateLevel.name, privateLevel.icon);
+ var privateInput = this._add_visiblity_choice(visibility_choices_container, "private", privateLevel.name, privateLevel.icon);
//Friends-visible post
var friendsLevel = ComunicWeb.components.posts.visibilityLevels.friends;
- var friendsInput = this._add_visiblity_choice(visibility_choices_contener, "friends", friendsLevel.name, friendsLevel.icon);
+ var friendsInput = this._add_visiblity_choice(visibility_choices_container, "friends", friendsLevel.name, friendsLevel.icon);
friendsInput.checked = true;
//Worldwide post
var publicLevel = ComunicWeb.components.posts.visibilityLevels.public;
- this._add_visiblity_choice(visibility_choices_contener, "public", publicLevel.name, publicLevel.icon);
+ this._add_visiblity_choice(visibility_choices_container, "public", publicLevel.name, publicLevel.icon);
//Add send button
var sendButton = createElem2({
@@ -459,7 +459,7 @@ ComunicWeb.components.posts.form = {
}
//Get the visibility level
- var visibilityLevel = visibility_choices_contener.querySelector("input:checked").value;
+ var visibilityLevel = visibility_choices_container.querySelector("input:checked").value;
datas.append("visibility", visibilityLevel);
//Lock the send button
@@ -495,14 +495,14 @@ ComunicWeb.components.posts.form = {
*/
_add_post_type: function(target, value, label){
- var postTypeContener = createElem2({
+ var postTypeContainer = createElem2({
appendTo: target,
type: "label",
class: "post-form-choice"
});
var input = createElem2({
- appendTo: postTypeContener,
+ appendTo: postTypeContainer,
type: "input",
elemType: "radio",
name: "post_type",
@@ -510,7 +510,7 @@ ComunicWeb.components.posts.form = {
});
createElem2({
- appendTo: postTypeContener,
+ appendTo: postTypeContainer,
type: "span",
innerHTML: label
});
@@ -530,14 +530,14 @@ ComunicWeb.components.posts.form = {
_add_visiblity_choice: function(target, value, title, icon){
//Visibility label
- var visibility_contener = createElem2({
+ var visibility_container = createElem2({
appendTo: target,
type: "label",
});
//Create input
var visibilityInput = createElem2({
- appendTo: visibility_contener,
+ appendTo: visibility_container,
type: "input",
elemType: "radio",
name: "post_visibility",
@@ -546,7 +546,7 @@ ComunicWeb.components.posts.form = {
//Create icon
var visibility_label = createElem2({
- appendTo: visibility_contener,
+ appendTo: visibility_container,
type: "span",
innerHTML: ""
});
diff --git a/assets/js/components/posts/ui.js b/assets/js/components/posts/ui.js
index 61d77f2f..6729085e 100644
--- a/assets/js/components/posts/ui.js
+++ b/assets/js/components/posts/ui.js
@@ -285,7 +285,7 @@ ComunicWeb.components.posts.ui = {
//In case of video
else if(infos.kind == "movie"){
- var videoContener = createElem2({
+ var videoContainer = createElem2({
appendTo: postRoot,
type: "div",
class: "post-video"
@@ -293,7 +293,7 @@ ComunicWeb.components.posts.ui = {
//Create video element
var video = createElem2({
- appendTo: videoContener,
+ appendTo: videoContainer,
type: "video",
class: "video-js vjs-default-skin"
});
@@ -439,7 +439,7 @@ ComunicWeb.components.posts.ui = {
class: "post-survey-question"
});
- //Answer contener
+ //Answer container
var surveyResponse = createElem2({
appendTo: postRoot,
type: "div",
@@ -449,7 +449,7 @@ ComunicWeb.components.posts.ui = {
var row = createElem2({
appendTo: postRoot,
type: "div",
- class: "row post-survey-chart-contener"
+ class: "row post-survey-chart-container"
});
//Create canvas column
@@ -459,8 +459,8 @@ ComunicWeb.components.posts.ui = {
class: "col-md-8"
});
- //Chart contener
- var chartContener = createElem2({
+ //Chart container
+ var chartContainer = createElem2({
appendTo: leftColumn,
type: "div",
class: "chart-responsive"
@@ -468,7 +468,7 @@ ComunicWeb.components.posts.ui = {
//Create canvas
var canvas = createElem2({
- appendTo: chartContener,
+ appendTo: chartContainer,
type: "canvas",
});
canvas.style.height = "150px";
diff --git a/assets/js/pages/userPage/main.js b/assets/js/pages/userPage/main.js
index 21781e97..ae8a2319 100644
--- a/assets/js/pages/userPage/main.js
+++ b/assets/js/pages/userPage/main.js
@@ -134,7 +134,7 @@ ComunicWeb.pages.userPage.main = {
var row = createElem2({
appendTo: sectionContent,
type: "div",
- class: "row page-contener"
+ class: "row page-container"
});
//Create left column
diff --git a/assets/js/pages/userPage/posts.js b/assets/js/pages/userPage/posts.js
index 2458a835..ca56c1f5 100644
--- a/assets/js/pages/userPage/posts.js
+++ b/assets/js/pages/userPage/posts.js
@@ -150,20 +150,20 @@ ComunicWeb.pages.userPage.posts = {
*/
_no_posts_msg: function(target){
- var msgContener = createElem2({
+ var msgContainer = createElem2({
appendTo: target,
type: "div"
});
var msgTitle = createElem2({
- appendTo: msgContener,
+ appendTo: msgContainer,
type: "h2",
innerHTML: "No post yet"
});
msgTitle.style.textAlign = "center";
var msgContent = createElem2({
- appendTo: msgContener,
+ appendTo: msgContainer,
type: "p",
innerHTML: "Nobody has posted a message on this page yet."
}).style.textAlign = "center";
diff --git a/assets/js/common/page.js b/assets/js/common/page.js
index 783ec675..2ae98edd 100644
--- a/assets/js/common/page.js
+++ b/assets/js/common/page.js
@@ -192,19 +192,19 @@ ComunicWeb.common.page = {
//Save new url
this._current_url = window.location.href.toString();
- //Get the main contener of the page
- var mainContenerElem = byId("wrapper");
+ //Get the main container of the page
+ var mainContainerElem = byId("wrapper");
//If we didn't get anything, clean the page and create a wrapper element
- if(!mainContenerElem){
- var mainContenerElem = this.emptyPage(true);
+ if(!mainContainerElem){
+ var mainContainerElem = this.emptyPage(true);
}
//We check if the page is a full screen page or not
if(pageInfos.disableMenus){
//We force the screen to be cleaned
- var mainContenerElem = this.emptyPage(true);
- var pageTarget = mainContenerElem; //The page directly goes to the main target
+ var mainContainerElem = this.emptyPage(true);
+ var pageTarget = mainContainerElem; //The page directly goes to the main target
}
//Else
else {
@@ -214,10 +214,10 @@ ComunicWeb.common.page = {
//We empty screen if we couldn't rich it
if(!pageTarget){
- mainContenerElem.innerHTML = "";
+ mainContainerElem.innerHTML = "";
//We create the pagetTarget element
- var pageTarget = createElem("div", mainContenerElem);
+ var pageTarget = createElem("div", mainContainerElem);
pageTarget.id = "pageTarget";
}
else{
@@ -290,7 +290,7 @@ ComunicWeb.common.page = {
/**
* Prepare a template load by specifiying datas
*
* @return {Object} The object contener with all required infos
*/
prepareLoadTemplate: function(){
//Create an object
@@ -310,10 +310,10 @@ ComunicWeb.common.page = {
* @param {Object} dataTemplate Datas to pass to the template (to parse it)
* @param {String} templateURI URI pointing on the template
* @param {function} afterParsingHTMLtemplate What to do once the template is loaded
* @param {Boolean} cleanContener Specify if contener has to be cleaned or not
* @return {Boolean} False if it fails
*/
- getAndShowTemplate: function(targetElem, dataTemplate, templateURI, afterParsingHTMLtemplate, cleanContener){
+ getAndShowTemplate: function(targetElem, dataTemplate, templateURI, afterParsingHTMLtemplate, cleanContainer){
//First, get the template URL
templateURL = ComunicWeb.__config.templatesURL + templateURI;
@@ -321,8 +321,8 @@ ComunicWeb.common.page = {
//Define how to apply the template
var afterDownloadTemplateContent = function(templateContent){
- //If required, clean the contener
- if(cleanContener){
+ //If required, clean the container
+ if(cleanContainer){
targetElem.innerHTML = "";
}
@@ -442,10 +442,10 @@ ComunicWeb.common.page = {
* @param {String} templateURI URI pointing on the template
* @param {Object} additionalData Additionnal to pass to the template
* @param {function} afterParsingJSONtemplate What to do once JSON template is loaded
* @param {Boolean} cleanContener Specify wether the template contener has to be cleaned or not
* @return {Boolean} Flase if it fails
*/
- getAndShowJSONtemplate: function(targetElem, templateURI, additionalData, afterParsingJSONtemplate, cleanContener){
+ getAndShowJSONtemplate: function(targetElem, templateURI, additionalData, afterParsingJSONtemplate, cleanContainer){
//Define template URL
var templateURL = ComunicWeb.__config.templatesURL + templateURI;
@@ -290,7 +290,7 @@ ComunicWeb.common.page = {
* Prepare a template load by specifiying datas
*
- * @return {Object} The object contener with all required infos
+ * @return {Object} The object container with all required infos
*/
prepareLoadTemplate: function(){
@@ -310,10 +310,10 @@ ComunicWeb.common.page = {
* @param {String} templateURI URI pointing on the template
* @param {function} afterParsingHTMLtemplate What to do once the template is loaded
- * @param {Boolean} cleanContener Specify if contener has to be cleaned or not
+ * @param {Boolean} cleanContainer Specify if container has to be cleaned or not
* @return {Boolean} False if it fails
*/
@@ -442,10 +442,10 @@ ComunicWeb.common.page = {
* @param {Object} additionalData Additionnal to pass to the template
* @param {function} afterParsingJSONtemplate What to do once JSON template is loaded
- * @param {Boolean} cleanContener Specify wether the template contener has to be cleaned or not
+ * @param {Boolean} cleanContainer Specify wether the template container has to be cleaned or not
* @return {Boolean} Flase if it fails
*/
diff --git a/assets/js/components/comments/ui.js b/assets/js/components/comments/ui.js
index d1bf3211..d1f03ff2 100644
--- a/assets/js/components/comments/ui.js
+++ b/assets/js/components/comments/ui.js
@@ -43,8 +43,8 @@ ComunicWeb.components.comments.ui = {
*/
_process_comments: function(infos, usersInfos, postID, target){
- //Create comments contener
- var contener = createElem2({
+ //Create comments container
+ var container = createElem2({
appendTo: target,
type: "div",
class: "box-comments post-comments"
@@ -52,12 +52,12 @@ ComunicWeb.components.comments.ui = {
//Process the list of comments
for(i in infos){
- this._show_comment(infos[i], usersInfos['user-' + infos[i].userID], contener);
+ this._show_comment(infos[i], usersInfos['user-' + infos[i].userID], container);
}
//Add comment creation form (if possible)
if(signed_in()){
- ComunicWeb.components.comments.form.display(postID, contener)
+ ComunicWeb.components.comments.form.display(postID, container)
}
},
@@ -95,10 +95,10 @@ ComunicWeb.components.comments.ui = {
*/
_show_comment: function(infos, user, target){
//Create comment contener (if required)
if(target.className != "box-comment"){
- var commentContener = createElem2({
+ var commentContainer = createElem2({
appendTo: target,
type: "div",
class: "box-comment"
@@ -106,16 +106,16 @@ ComunicWeb.components.comments.ui = {
}
//Empty comment contener
else {
emptyElem(target);
- var commentContener = target;
+ var commentContainer = target;
}
//Add user image
createElem2({
- appendTo: commentContener,
+ appendTo: commentContainer,
type: "img",
class: "img-circle imgs-sm",
src: user.accountImage
@@ -123,13 +123,13 @@ ComunicWeb.components.comments.ui = {
//Create comment text
var commentText = createElem2({
- appendTo: commentContener,
+ appendTo: commentContainer,
type: "div",
class: "comment-text"
});
//Add username
- var userNameContener = createElem2({
+ var userNameContainer = createElem2({
appendTo: commentText,
type: "span",
class: "username",
@@ -137,15 +137,15 @@ ComunicWeb.components.comments.ui = {
});
//Add right elements
- var rightContener = createElem2({
- appendTo: userNameContener,
+ var rightContainer = createElem2({
+ appendTo: userNameContainer,
type: "span",
class: "text-muted pull-right"
});
//Add comment creation date
createElem2({
- appendTo: rightContener,
+ appendTo: rightContainer,
type: "span",
innerHTML: ComunicWeb.common.date.timeDiffToStr(infos.time_sent) + " ago"
});
@@ -155,7 +155,7 @@ ComunicWeb.components.comments.ui = {
//Create a button to update the comment
var editCommentLink = createElem2({
- appendTo: rightContener,
+ appendTo: rightContainer,
type: "a",
class: "edit-comment-link"
});
@@ -170,14 +170,14 @@ ComunicWeb.components.comments.ui = {
editCommentLink.onclick = function(){
//Open comment editor
- ComunicWeb.components.comments.editor.open(infos, commentContener);
+ ComunicWeb.components.comments.editor.open(infos, commentContainer);
}
//Create a button to delete the comment
var deleteCommentLink = createElem2({
- appendTo: rightContener,
+ appendTo: rightContainer,
type: "a",
class: "delete-comment-link"
});
@@ -198,12 +198,12 @@ ComunicWeb.components.comments.ui = {
return;
//Hide the comment
- commentContener.style.visibility = "hidden";
+ commentContainer.style.visibility = "hidden";
//Delete the comment
ComunicWeb.components.comments.interface.delete(infos.ID, function(response){
- commentContener.style.visibility = "visible";
+ commentContainer.style.visibility = "visible";
//Check for errors
if(response.error){
@@ -212,8 +212,8 @@ ComunicWeb.components.comments.ui = {
}
//Delete the comment node
- emptyElem(commentContener);
- commentContener.remove();
+ emptyElem(commentContainer);
+ commentContainer.remove();
});
});
@@ -237,14 +237,14 @@ ComunicWeb.components.comments.ui = {
//Add comment image (if any)
if(infos.img_url != null){
- var commentImageContener = createElem2({
+ var commentImageContainer = createElem2({
appendTo: commentText,
type: "div",
- class: "comment-img-contener"
+ class: "comment-img-container"
});
var commentImageLink = createElem2({
- appendTo: commentImageContener,
+ appendTo: commentImageContainer,
type: "a",
href: infos.img_url
});
@@ -95,10 +95,10 @@ ComunicWeb.components.comments.ui = {
*/
_show_comment: function(infos, user, target){
- //Create comment contener (if required)
+ //Create comment container (if required)
if(target.className != "box-comment"){
@@ -106,16 +106,16 @@ ComunicWeb.components.comments.ui = {
}
- //Empty comment contener
+ //Empty comment container
else {
emptyElem(target);
diff --git a/assets/js/components/conversations/chatWindows.js b/assets/js/components/conversations/chatWindows.js
index 61257876..642eecdf 100644
--- a/assets/js/components/conversations/chatWindows.js
+++ b/assets/js/components/conversations/chatWindows.js
@@ -24,7 +24,7 @@ ComunicWeb.components.conversations.chatWindows = {
//Create a conversation window
var conversationWindow = this.create({
- target: byId(ComunicWeb.components.conversations.manager.__conversationsContenerID),
+ target: byId(ComunicWeb.components.conversations.manager.__conversationsContainerID),
conversationID: conversationID,
});
@@ -75,7 +75,7 @@ ComunicWeb.components.conversations.chatWindows = {
//Debug
//Create messages contener
infosBox.messagesArea = createElem2({
appendTo: infosBox.boxBody,
type: "div",
@@ -120,8 +120,8 @@ ComunicWeb.components.conversations.chatWindows = {
*/
addMessageform: function(infosBox){
- //Create form contener
- var conversationFormContener = createElem2({
+ //Create form container
+ var conversationFormContainer = createElem2({
appendTo: infosBox.boxFooter,
type: "form",
class: "create-message-form"
@@ -129,7 +129,7 @@ ComunicWeb.components.conversations.chatWindows = {
//Create input group
var inputGroup = createElem2({
- appendTo: conversationFormContener,
+ appendTo: conversationFormContainer,
type: "div",
class: "input-group"
});
@@ -209,7 +209,7 @@ ComunicWeb.components.conversations.chatWindows = {
//Add required elements to infosBox
infosBox.sendMessageForm = {
- formRoot: conversationFormContener,
+ formRoot: conversationFormContainer,
sendButton: sendButton,
inputText: inputText,
textarea2: textarea2,
@@ -75,7 +75,7 @@ ComunicWeb.components.conversations.chatWindows = {
//Debug
- //Create messages contener
+ //Create messages container
infosBox.messagesArea = createElem2({
appendTo: infosBox.boxBody,
diff --git a/assets/js/components/friends/listModal.js b/assets/js/components/friends/listModal.js
index b239d318..4873b217 100644
--- a/assets/js/components/friends/listModal.js
+++ b/assets/js/components/friends/listModal.js
@@ -162,7 +162,7 @@ ComunicWeb.components.friends.listModal = {
*/
_show_read_only: function(target, ids, user){
//Create the friends list contener
var list = createElem2({
appendTo: target,
type: "div",
@@ -182,7 +182,7 @@ ComunicWeb.components.friends.listModal = {
ids.forEach(id => {
//Display the user
- const userContener = createElem2({
+ const userContainer = createElem2({
appendTo: list,
type: "div",
class: "friend"
@@ -190,7 +190,7 @@ ComunicWeb.components.friends.listModal = {
//Create user link
const userLink = createElem2({
- appendTo: userContener,
+ appendTo: userContainer,
type: "a"
});
@@ -162,7 +162,7 @@ ComunicWeb.components.friends.listModal = {
*/
_show_read_only: function(target, ids, user){
- //Create the friends list contener
+ //Create the friends list container
var list = createElem2({
appendTo: target,
diff --git a/assets/js/components/friends/ui.js b/assets/js/components/friends/ui.js
index 62b98c7d..e97dd98d 100644
--- a/assets/js/components/friends/ui.js
+++ b/assets/js/components/friends/ui.js
@@ -15,13 +15,13 @@ ComunicWeb.components.friends.ui = {
*/
show_personnal_friend: function(target, friend, user){
//Create friend contener, if required
if(target.className == "friend"){
- var friendContener = target;
- emptyElem(friendContener);
+ var friendContainer = target;
+ emptyElem(friendContainer);
}
else
- var friendContener = createElem2({
+ var friendContainer = createElem2({
appendTo: target,
type: "div",
class: "friend"
@@ -32,7 +32,7 @@ ComunicWeb.components.friends.ui = {
//Create user link
const userLink = createElem2({
- appendTo: friendContener,
+ appendTo: friendContainer,
type: "a"
});
@@ -64,7 +64,7 @@ ComunicWeb.components.friends.ui = {
//Create actions area
var actionsOnFriendArea = createElem2({
- appendTo: friendContener,
+ appendTo: friendContainer,
type: "div",
class: "friends-actions"
});
@@ -112,12 +112,12 @@ ComunicWeb.components.friends.ui = {
}
if(!accept){
- friendContener.remove();
+ friendContainer.remove();
}
else {
//Update friendship informations
- ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContener);
+ ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContainer);
}
});
@@ -165,7 +165,7 @@ ComunicWeb.components.friends.ui = {
}
//Update friendship informations
- ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContener);
+ ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContainer);
});
}
@@ -199,7 +199,7 @@ ComunicWeb.components.friends.ui = {
ComunicWeb.common.notificationSystem.showNotification("Could not update posts creation status !", "danger");
//Update friendship informations
- ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContener);
+ ComunicWeb.components.friends.actions.refresh_single_personnal(friendID, friendContainer);
});
}
@@ -209,7 +209,7 @@ ComunicWeb.components.friends.ui = {
//Offer to delete friendship
const deleteLink = createElem2({
- appendTo: friendContener,
+ appendTo: friendContainer,
type: "a",
innerHTML: ""
});
@@ -225,11 +225,11 @@ ComunicWeb.components.friends.ui = {
return;
//Try to delete the friend from the list
- friendContener.style.visibility = "hidden";
+ friendContainer.style.visibility = "hidden";
ComunicWeb.components.friends.interface.remove_friend(friendID, function(result){
- //Make friend contener visible
- friendContener.style.visibility = "visible";
+ //Make friend container visible
+ friendContainer.style.visibility = "visible";
//Check for errors
if(result.error){
@@ -238,7 +238,7 @@ ComunicWeb.components.friends.ui = {
}
//Delete the element
- friendContener.remove();
+ friendContainer.remove();
});
@@ -15,13 +15,13 @@ ComunicWeb.components.friends.ui = {
*/
show_personnal_friend: function(target, friend, user){
- //Create friend contener, if required
+ //Create friend container, if required
if(target.className == "friend"){
diff --git a/assets/js/pages/userPage/profileInfos.js b/assets/js/pages/userPage/profileInfos.js
index e78d1e1b..d5804779 100644
--- a/assets/js/pages/userPage/profileInfos.js
+++ b/assets/js/pages/userPage/profileInfos.js
@@ -33,8 +33,8 @@ ComunicWeb.pages.userPage.profileInfos = {
*/
createMainBox: function(infos, target){
- //Create box contener
- var boxContener = createElem2({
+ //Create box container
+ var boxContainer = createElem2({
appendTo: target,
type: "div",
class: "box box-primary"
@@ -42,7 +42,7 @@ ComunicWeb.pages.userPage.profileInfos = {
//Setup box body
var boxBody = createElem2({
- appendTo: boxContener,
+ appendTo: boxContainer,
type: "div",
class: "box-body box-profile"
});